@@ -525,11 +525,7 @@ protected:
 
 
 protected:
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     void enterEvent (QEnterEvent *e) override;
-#else
-    void enterEvent (QEvent *e) override;
-#endif
     void leaveEvent (QEvent *e) override;
 
 
